# -*- coding: utf-8 -*-
'''
Created on Fri Jan 24 08:15:36 2025

@author: mstep
'''

# For information about text anchors, see:
#   https://pillow.readthedocs.io/en/stable/handbook/text-anchors.html#text-anchors

#%%
import tkinter as tk
from PIL import Image, ImageDraw, ImageTk, ImageFont

class PilAlignTextApp:
    def __init__(self):
        self.window = tk.Tk()

        self.window.title('pil_align_text')
        self.window.protocol('WM_DELETE_WINDOW', self.kill_callback)
        self.window.geometry('300x300')

        # Drawing parameters.
        wid = 300
        hgt = 300
        margin = 10

        # Make a frame holding radio buttons.
        frame = tk.Frame(self.window)
        frame.pack(side=tk.TOP, anchor=tk.W, padx=5, pady=(5,0))
        label = tk.Label(frame, text='Alignment:')
        label.pack(side=tk.LEFT)
        self.alignment_value = tk.StringVar(value='left')
        left_button = tk.Radiobutton(frame, variable=self.alignment_value,
            command=self.draw_samples, text='Left', value='left')
        left_button.pack(side=tk.LEFT, padx=10)
        center_button = tk.Radiobutton(frame, variable=self.alignment_value,
            command=self.draw_samples, text='Center', value='center')
        center_button.pack(side=tk.LEFT, padx=10)
        right_button = tk.Radiobutton(frame, variable=self.alignment_value,
            command=self.draw_samples, text='Right', value='right')
        right_button.pack(side=tk.LEFT, padx=10)

        # Make the canvas.
        self.canvas = tk.Canvas(self.window, bg='white',
            width=wid, height=hgt,
            borderwidth=0, highlightthickness=0)
        self.canvas.pack(side=tk.TOP, anchor=tk.NW, padx=margin, pady=margin)

        # Display the initial samples.
        self.draw_samples()

        # Size the window to fit.
        self.window.geometry(f'{wid + 2 * margin}x{hgt + 2 * margin}')

        # Display the window.
        self.window.focus_force()
        self.window.mainloop()

    def draw_samples(self):
        '''Draw text samples.'''
        # Create the PIL image.
        wid = 300
        hgt = 300
        image = Image.new('RGB', (wid, hgt), 'white')

        # Create a Draw object to draw on the image.
        dr = ImageDraw.Draw(image)

        # Get the font.
        font_size = 20
        font = ImageFont.truetype('timesbi.ttf', font_size)        

        # Get the selected alignment.
        align = self.alignment_value.get()

        # Draw the samples.
        x = 4 * font_size
        y = font_size
        self.draw_sample(dr, font, x, y, align, 'ms')

        y += 5 * font_size
        self.draw_sample(dr, font, x, y, align, 'mm')

        x = 15
        y += 4 * font_size
        self.draw_sample(dr, font, x, y, align, 'lm')

        x = 4 * font_size
        x += 7 * font_size
        y = font_size
        self.draw_sample(dr, font, x, y, align, 'ma')

        x += 3 * font_size
        y += 6 * font_size
        self.draw_sample(dr, font, x, y, align, 'rm')

        y += 6 * font_size
        self.draw_sample(dr, font, x, y, align, 'rd')

        # Convert the image into a PhotoImage for tkinter to display.
        self.photo_image = ImageTk.PhotoImage(image)

        # Display the result.
        self.canvas.delete(tk.ALL)
        self.canvas.create_image(0, 0, image=self.photo_image, anchor=tk.NW)

    def draw_sample(self, dr, font, x, y, align, anchor):
        radius = 3
        text = f'The first line\nAnchor: {anchor}\nLine 3'
        dr.multiline_text((x, y), text=text,
            fill='blue', font=font, anchor=anchor, align=align)
        dr.ellipse((x - radius, y - radius, x + radius, y + radius),
            fill='yellow', outline='black')

    def kill_callback(self):
        # Destroy the tkinter window.
        self.window.destroy()

#%%
PilAlignTextApp()
print('Done')
